import { EnvironmentProviders } from '@angular/core';
import { Elements } from './elements';
/**
 * A declarative approach to register Angular Elements.
 *
 * The elements can be either provided synchronously or asynchronously
 * via a promise.
 *
 * @remarks Noop if the current platform is not browser.
 *
 * @example
 *  ```ts
 *  export const appElements: Elements = {
 *    'my-button': ButtonComponent,
 *    'my-icon': IconComponent,
 *    'my-icon-button': IconButtonComponent,
 *  };
 *  ```
 *  ```ts
 *  providers: [
 *    provideElements(appElements),
 *  ]
 *  ```
 *  ```ts
 *  providers: [
 *    provideElements(import('./app-elements').then(m => m.appElements)),
 *  ]
 *  ```
 */
export declare function provideElements(elements: Elements | Promise<Elements>): EnvironmentProviders;
